# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/summary.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/summary.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import file_pointer_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_file__pointer__pb2
from yandex.cloud.loadtesting.api.v1.test import imbalance_point_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_imbalance__point__pb2
from yandex.cloud.loadtesting.api.v1.test import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_status__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/loadtesting/api/v1/test/summary.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x37yandex/cloud/loadtesting/api/v1/test/file_pointer.proto\x1a:yandex/cloud/loadtesting/api/v1/test/imbalance_point.proto\x1a\x31yandex/cloud/loadtesting/api/v1/test/status.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc0\x03\n\x07Summary\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.yandex.cloud.loadtesting.api.v1.test.Status\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bis_finished\x18\x06 \x01(\x08\x12\r\n\x05\x65rror\x18\x07 \x01(\t\x12M\n\x0fimbalance_point\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.test.ImbalancePoint\x12\x19\n\x11\x61ssigned_agent_id\x18\t \x01(\t\x12\x44\n\tartifacts\x18\n \x01(\x0b\x32\x31.yandex.cloud.loadtesting.api.v1.test.FilePointerBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.summary_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_SUMMARY']._serialized_start=294
  _globals['_SUMMARY']._serialized_end=742
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.apploadbalancer.v1.payload_pb2
import yandex.cloud.apploadbalancer.v1.rate_limit_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VirtualHost(google.protobuf.message.Message):
    """A virtual host resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#virtual-host).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    MODIFY_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    MODIFY_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    RATE_LIMIT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the virtual host. The name is unique within the HTTP router."""
    @property
    def authority(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of domains that are attributed to the virtual host.

        The host is selected to process the request received by the load balancer
        if the domain specified in the HTTP/1.1 `Host` header or the HTTP/2 `:authority` pseudo-header matches a domain
        specified in the host.

        A wildcard asterisk character (`*`) matches 0 or more characters.

        If not specified, all domains are attributed to the host, which is the same as specifying a `*` value.
        An HTTP router must not contain more than one virtual host to which all domains are attributed.
        """

    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]:
        """Routes of the virtual host.

        A route contains a set of conditions (predicates) that are used by the load balancer to select the route
        for the request and an action on the request.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#routes).

        The order of routes matters: the first route whose predicate matches the request is selected.
        The most specific routes should be at the top of the list, so that they are not overridden.
        For example, if the first HTTP route is configured, via [HttpRoute.match], to match paths prefixed with just `/`,
        other routes are never matched.
        """

    @property
    def modify_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderModification]:
        """Deprecated, use route_options.modify_request_headers."""

    @property
    def modify_response_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderModification]:
        """Deprecated, use route_options.modify_response_headers."""

    @property
    def route_options(self) -> global___RouteOptions: ...
    @property
    def rate_limit(self) -> yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit:
        """RateLimit is a rate limit configuration applied for a whole virtual host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        authority: collections.abc.Iterable[builtins.str] | None = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
        modify_request_headers: collections.abc.Iterable[global___HeaderModification] | None = ...,
        modify_response_headers: collections.abc.Iterable[global___HeaderModification] | None = ...,
        route_options: global___RouteOptions | None = ...,
        rate_limit: yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rate_limit", b"rate_limit", "route_options", b"route_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["authority", b"authority", "modify_request_headers", b"modify_request_headers", "modify_response_headers", b"modify_response_headers", "name", b"name", "rate_limit", b"rate_limit", "route_options", b"route_options", "routes", b"routes"]) -> None: ...

global___VirtualHost = VirtualHost

@typing.final
class RouteOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODIFY_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    MODIFY_RESPONSE_HEADERS_FIELD_NUMBER: builtins.int
    RBAC_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_ID_FIELD_NUMBER: builtins.int
    security_profile_id: builtins.str
    """Security profile that will take effect to all requests routed via particular virtual host."""
    @property
    def modify_request_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderModification]:
        """Apply the following modifications to the request headers."""

    @property
    def modify_response_headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderModification]:
        """Apply the following modifications to the response headers."""

    @property
    def rbac(self) -> global___RBAC: ...
    def __init__(
        self,
        *,
        modify_request_headers: collections.abc.Iterable[global___HeaderModification] | None = ...,
        modify_response_headers: collections.abc.Iterable[global___HeaderModification] | None = ...,
        rbac: global___RBAC | None = ...,
        security_profile_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rbac", b"rbac"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["modify_request_headers", b"modify_request_headers", "modify_response_headers", b"modify_response_headers", "rbac", b"rbac", "security_profile_id", b"security_profile_id"]) -> None: ...

global___RouteOptions = RouteOptions

@typing.final
class RBAC(google.protobuf.message.Message):
    """Role Based Access Control (RBAC) provides router, virtual host, and route access control for the ALB
    service. Requests are allowed or denied based on the `action` and whether a matching principal is
    found. For instance, if the action is ALLOW and a matching principal is found the request should be
    allowed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RBAC._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: RBAC._Action.ValueType  # 0
        ALLOW: RBAC._Action.ValueType  # 1
        """Allows the request if and only if there is a principal that matches the request."""
        DENY: RBAC._Action.ValueType  # 2
        """Allows the request if and only if there are no principal that match the request."""

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    ACTION_UNSPECIFIED: RBAC.Action.ValueType  # 0
    ALLOW: RBAC.Action.ValueType  # 1
    """Allows the request if and only if there is a principal that matches the request."""
    DENY: RBAC.Action.ValueType  # 2
    """Allows the request if and only if there are no principal that match the request."""

    ACTION_FIELD_NUMBER: builtins.int
    PRINCIPALS_FIELD_NUMBER: builtins.int
    action: global___RBAC.Action.ValueType
    """The action to take if a principal matches. Every action either allows or denies a request."""
    @property
    def principals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Principals]:
        """Required. A match occurs when at least one matches the request."""

    def __init__(
        self,
        *,
        action: global___RBAC.Action.ValueType = ...,
        principals: collections.abc.Iterable[global___Principals] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "principals", b"principals"]) -> None: ...

global___RBAC = RBAC

@typing.final
class Principals(google.protobuf.message.Message):
    """Principals define a group of identities for a request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AND_PRINCIPALS_FIELD_NUMBER: builtins.int
    @property
    def and_principals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Principal]:
        """Required. A match occurs when all principals match the request."""

    def __init__(
        self,
        *,
        and_principals: collections.abc.Iterable[global___Principal] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["and_principals", b"and_principals"]) -> None: ...

global___Principals = Principals

@typing.final
class Principal(google.protobuf.message.Message):
    """Principal defines an identity for a request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeaderMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Specifies the name of the header in the request."""
        @property
        def value(self) -> global___StringMatch:
            """Specifies how the header match will be performed to route the request.
            In the absence of value a request that has specified header name will match,
            regardless of the header's value.
            """

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: global___StringMatch | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    HEADER_FIELD_NUMBER: builtins.int
    REMOTE_IP_FIELD_NUMBER: builtins.int
    ANY_FIELD_NUMBER: builtins.int
    remote_ip: builtins.str
    """A CIDR block or IP that describes the request remote/origin address, e.g. ``192.0.0.0/24`` or``192.0.0.4`` ."""
    any: builtins.bool
    """When any is set, it matches any request."""
    @property
    def header(self) -> global___Principal.HeaderMatcher:
        """A header (or pseudo-header such as :path or :method) of the incoming HTTP request."""

    def __init__(
        self,
        *,
        header: global___Principal.HeaderMatcher | None = ...,
        remote_ip: builtins.str = ...,
        any: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["any", b"any", "header", b"header", "identifier", b"identifier", "remote_ip", b"remote_ip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["any", b"any", "header", b"header", "identifier", b"identifier", "remote_ip", b"remote_ip"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["identifier", b"identifier"]) -> typing.Literal["header", "remote_ip", "any"] | None: ...

global___Principal = Principal

@typing.final
class HeaderModification(google.protobuf.message.Message):
    """A header modification resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    APPEND_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    RENAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the header."""
    append: builtins.str
    """Appends the specified string to the header value.

    Variables [defined for Envoy proxy](https://www.envoyproxy.io/docs/envoy/latest/configuration/http/http_conn_man/headers#custom-request-response-headers)
    are supported.
    """
    replace: builtins.str
    """Replaces the value of the header with the specified string.

    Variables [defined for Envoy proxy](https://www.envoyproxy.io/docs/envoy/latest/configuration/http/http_conn_man/headers#custom-request-response-headers)
    are supported.
    """
    remove: builtins.bool
    """Removes the header."""
    rename: builtins.str
    """Replaces the name of the header with the specified string.
    This operation is only supported for ALB Virtual Hosts.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        append: builtins.str = ...,
        replace: builtins.str = ...,
        remove: builtins.bool = ...,
        rename: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["append", b"append", "operation", b"operation", "remove", b"remove", "rename", b"rename", "replace", b"replace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["append", b"append", "name", b"name", "operation", b"operation", "remove", b"remove", "rename", b"rename", "replace", b"replace"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["operation", b"operation"]) -> typing.Literal["append", "replace", "remove", "rename"] | None: ...

global___HeaderModification = HeaderModification

@typing.final
class Route(google.protobuf.message.Message):
    """A route resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#routes).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    GRPC_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    DISABLE_SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the route."""
    disable_security_profile: builtins.bool
    """Whether set to 'true' disables security profile for the route."""
    @property
    def http(self) -> global___HttpRoute:
        """HTTP route configuration."""

    @property
    def grpc(self) -> global___GrpcRoute:
        """gRPC route configuration."""

    @property
    def route_options(self) -> global___RouteOptions: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        http: global___HttpRoute | None = ...,
        grpc: global___GrpcRoute | None = ...,
        route_options: global___RouteOptions | None = ...,
        disable_security_profile: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["grpc", b"grpc", "http", b"http", "route", b"route", "route_options", b"route_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disable_security_profile", b"disable_security_profile", "grpc", b"grpc", "http", b"http", "name", b"name", "route", b"route", "route_options", b"route_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["route", b"route"]) -> typing.Literal["http", "grpc"] | None: ...

global___Route = Route

@typing.final
class HttpRoute(google.protobuf.message.Message):
    """An HTTP route configuration resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    REDIRECT_FIELD_NUMBER: builtins.int
    DIRECT_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def match(self) -> global___HttpRouteMatch:
        """Condition (predicate) used to select the route."""

    @property
    def route(self) -> global___HttpRouteAction:
        """Forwards the request to a backend group for processing as configured."""

    @property
    def redirect(self) -> global___RedirectAction:
        """Redirects the request as configured."""

    @property
    def direct_response(self) -> global___DirectResponseAction:
        """Instructs the load balancer to respond directly as configured."""

    def __init__(
        self,
        *,
        match: global___HttpRouteMatch | None = ...,
        route: global___HttpRouteAction | None = ...,
        redirect: global___RedirectAction | None = ...,
        direct_response: global___DirectResponseAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "direct_response", b"direct_response", "match", b"match", "redirect", b"redirect", "route", b"route"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "direct_response", b"direct_response", "match", b"match", "redirect", b"redirect", "route", b"route"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["route", "redirect", "direct_response"] | None: ...

global___HttpRoute = HttpRoute

@typing.final
class GrpcRoute(google.protobuf.message.Message):
    """A gRPC route configuration resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    STATUS_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def match(self) -> global___GrpcRouteMatch:
        """Condition (predicate) used to select the route."""

    @property
    def route(self) -> global___GrpcRouteAction:
        """Forwards the request to a backend group for processing as configured."""

    @property
    def status_response(self) -> global___GrpcStatusResponseAction:
        """Instructs the load balancer to respond directly with a specified status."""

    def __init__(
        self,
        *,
        match: global___GrpcRouteMatch | None = ...,
        route: global___GrpcRouteAction | None = ...,
        status_response: global___GrpcStatusResponseAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "match", b"match", "route", b"route", "status_response", b"status_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "match", b"match", "route", b"route", "status_response", b"status_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["route", "status_response"] | None: ...

global___GrpcRoute = GrpcRoute

@typing.final
class HttpRouteHeaderMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the HTTP Header to be matched."""
    @property
    def value(self) -> global___StringMatch:
        """Value of HTTP Header to be matched."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: global___StringMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

global___HttpRouteHeaderMatch = HttpRouteHeaderMatch

@typing.final
class HttpRouteQueryParamMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the HTTP query parameter to be matched."""
    @property
    def value(self) -> global___StringMatch:
        """Value of HTTP query parameter to be matched."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: global___StringMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

global___HttpRouteQueryParamMatch = HttpRouteQueryParamMatch

@typing.final
class HttpRouteMatch(google.protobuf.message.Message):
    """An HTTP route condition (predicate) resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_METHOD_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def http_method(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """HTTP method specified in the request."""

    @property
    def path(self) -> global___StringMatch:
        """Match settings for the path specified in the request.

        If not specified, the route matches all paths.
        """

    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpRouteHeaderMatch]:
        """Headers specify HTTP request header matchers. Multiple match values are
        ANDed together, meaning, a request must match all the specified headers
        to select the route. Headers must be unique.
        """

    @property
    def query_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpRouteQueryParamMatch]:
        """Query Parameters specify HTTP query parameter matchers. Multiple match
        values are ANDed together, meaning, a request must match all the
        specified query parameters to select the route. Query parameters must be unique.
        """

    def __init__(
        self,
        *,
        http_method: collections.abc.Iterable[builtins.str] | None = ...,
        path: global___StringMatch | None = ...,
        headers: collections.abc.Iterable[global___HttpRouteHeaderMatch] | None = ...,
        query_parameters: collections.abc.Iterable[global___HttpRouteQueryParamMatch] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["path", b"path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "http_method", b"http_method", "path", b"path", "query_parameters", b"query_parameters"]) -> None: ...

global___HttpRouteMatch = HttpRouteMatch

@typing.final
class GrpcRouteMatch(google.protobuf.message.Message):
    """A gRPC route condition (predicate) resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQMN_FIELD_NUMBER: builtins.int
    @property
    def fqmn(self) -> global___StringMatch:
        """Match settings for gRPC service method called in the request.

        A match string must be a fully qualified method name, e.g. `foo.bar.v1.BazService/Get`, or a prefix of such.

        If not specified, the route matches all methods.
        """

    def __init__(
        self,
        *,
        fqmn: global___StringMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fqmn", b"fqmn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fqmn", b"fqmn"]) -> None: ...

global___GrpcRouteMatch = GrpcRouteMatch

@typing.final
class StringMatch(google.protobuf.message.Message):
    """A string matcher resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    """Exact match string."""
    prefix_match: builtins.str
    """Prefix match string."""
    regex_match: builtins.str
    """Regular expression match string."""
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        prefix_match: builtins.str = ...,
        regex_match: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["exact_match", b"exact_match", "match", b"match", "prefix_match", b"prefix_match", "regex_match", b"regex_match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exact_match", b"exact_match", "match", b"match", "prefix_match", b"prefix_match", "regex_match", b"regex_match"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["match", b"match"]) -> typing.Literal["exact_match", "prefix_match", "regex_match"] | None: ...

global___StringMatch = StringMatch

@typing.final
class RedirectAction(google.protobuf.message.Message):
    """A redirect action resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RedirectResponseCode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RedirectResponseCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RedirectAction._RedirectResponseCode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MOVED_PERMANENTLY: RedirectAction._RedirectResponseCode.ValueType  # 0
        """`301 Moved Permanently` status code."""
        FOUND: RedirectAction._RedirectResponseCode.ValueType  # 1
        """`302 Found` status code."""
        SEE_OTHER: RedirectAction._RedirectResponseCode.ValueType  # 2
        """`303 See Other` status code."""
        TEMPORARY_REDIRECT: RedirectAction._RedirectResponseCode.ValueType  # 3
        """`307 Temporary Redirect` status code."""
        PERMANENT_REDIRECT: RedirectAction._RedirectResponseCode.ValueType  # 4
        """`308 Permanent Redirect` status code."""

    class RedirectResponseCode(_RedirectResponseCode, metaclass=_RedirectResponseCodeEnumTypeWrapper):
        """HTTP status codes supported for use in redirect responses."""

    MOVED_PERMANENTLY: RedirectAction.RedirectResponseCode.ValueType  # 0
    """`301 Moved Permanently` status code."""
    FOUND: RedirectAction.RedirectResponseCode.ValueType  # 1
    """`302 Found` status code."""
    SEE_OTHER: RedirectAction.RedirectResponseCode.ValueType  # 2
    """`303 See Other` status code."""
    TEMPORARY_REDIRECT: RedirectAction.RedirectResponseCode.ValueType  # 3
    """`307 Temporary Redirect` status code."""
    PERMANENT_REDIRECT: RedirectAction.RedirectResponseCode.ValueType  # 4
    """`308 Permanent Redirect` status code."""

    REPLACE_SCHEME_FIELD_NUMBER: builtins.int
    REPLACE_HOST_FIELD_NUMBER: builtins.int
    REPLACE_PORT_FIELD_NUMBER: builtins.int
    REPLACE_PATH_FIELD_NUMBER: builtins.int
    REPLACE_PREFIX_FIELD_NUMBER: builtins.int
    REMOVE_QUERY_FIELD_NUMBER: builtins.int
    RESPONSE_CODE_FIELD_NUMBER: builtins.int
    replace_scheme: builtins.str
    """URI scheme replacement.

    If `http` or `https` scheme is to be replaced and `80` or `443` port is specified in the original URI,
    the port is also removed.

    If not specified, the original scheme and port are used.
    """
    replace_host: builtins.str
    """URI host replacement.

    If not specified, the original host is used.
    """
    replace_port: builtins.int
    """URI host replacement.

    If not specified, the original host is used.
    """
    replace_path: builtins.str
    """Replacement for the whole path."""
    replace_prefix: builtins.str
    """Replacement for the path prefix matched by [StringMatch].

    For instance, if [StringMatch.prefix_match] value is `/foo` and `replace_prefix` value is `/bar`,
    a request with `https://example.com/foobaz` URI is redirected to `https://example.com/barbaz`.
    For [StringMatch.exact_match], the whole path is replaced.
    """
    remove_query: builtins.bool
    """Removes URI query."""
    response_code: global___RedirectAction.RedirectResponseCode.ValueType
    """HTTP status code to use in redirect responses."""
    def __init__(
        self,
        *,
        replace_scheme: builtins.str = ...,
        replace_host: builtins.str = ...,
        replace_port: builtins.int = ...,
        replace_path: builtins.str = ...,
        replace_prefix: builtins.str = ...,
        remove_query: builtins.bool = ...,
        response_code: global___RedirectAction.RedirectResponseCode.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["path", b"path", "replace_path", b"replace_path", "replace_prefix", b"replace_prefix"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["path", b"path", "remove_query", b"remove_query", "replace_host", b"replace_host", "replace_path", b"replace_path", "replace_port", b"replace_port", "replace_prefix", b"replace_prefix", "replace_scheme", b"replace_scheme", "response_code", b"response_code"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["path", b"path"]) -> typing.Literal["replace_path", "replace_prefix"] | None: ...

global___RedirectAction = RedirectAction

@typing.final
class DirectResponseAction(google.protobuf.message.Message):
    """A direct response action resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    status: builtins.int
    """HTTP status code to use in responses."""
    @property
    def body(self) -> yandex.cloud.apploadbalancer.v1.payload_pb2.Payload:
        """Response body."""

    def __init__(
        self,
        *,
        status: builtins.int = ...,
        body: yandex.cloud.apploadbalancer.v1.payload_pb2.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["body", b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "status", b"status"]) -> None: ...

global___DirectResponseAction = DirectResponseAction

@typing.final
class GrpcStatusResponseAction(google.protobuf.message.Message):
    """A gRPC status response action resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GrpcStatusResponseAction._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OK: GrpcStatusResponseAction._Status.ValueType  # 0
        """`OK` (0) status code."""
        INVALID_ARGUMENT: GrpcStatusResponseAction._Status.ValueType  # 1
        """`INVALID_ARGUMENT` (3) status code."""
        NOT_FOUND: GrpcStatusResponseAction._Status.ValueType  # 2
        """`NOT_FOUND` (5) status code."""
        PERMISSION_DENIED: GrpcStatusResponseAction._Status.ValueType  # 3
        """`PERMISSION_DENIED` (7) status code."""
        UNAUTHENTICATED: GrpcStatusResponseAction._Status.ValueType  # 4
        """`UNAUTHENTICATED` (16) status code."""
        UNIMPLEMENTED: GrpcStatusResponseAction._Status.ValueType  # 5
        """`UNIMPLEMENTED` (12) status code."""
        INTERNAL: GrpcStatusResponseAction._Status.ValueType  # 6
        """`INTERNAL` (13) status code."""
        UNAVAILABLE: GrpcStatusResponseAction._Status.ValueType  # 7
        """`UNAVAILABLE` (14) status code."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """gRPC status code supported for use in responses."""

    OK: GrpcStatusResponseAction.Status.ValueType  # 0
    """`OK` (0) status code."""
    INVALID_ARGUMENT: GrpcStatusResponseAction.Status.ValueType  # 1
    """`INVALID_ARGUMENT` (3) status code."""
    NOT_FOUND: GrpcStatusResponseAction.Status.ValueType  # 2
    """`NOT_FOUND` (5) status code."""
    PERMISSION_DENIED: GrpcStatusResponseAction.Status.ValueType  # 3
    """`PERMISSION_DENIED` (7) status code."""
    UNAUTHENTICATED: GrpcStatusResponseAction.Status.ValueType  # 4
    """`UNAUTHENTICATED` (16) status code."""
    UNIMPLEMENTED: GrpcStatusResponseAction.Status.ValueType  # 5
    """`UNIMPLEMENTED` (12) status code."""
    INTERNAL: GrpcStatusResponseAction.Status.ValueType  # 6
    """`INTERNAL` (13) status code."""
    UNAVAILABLE: GrpcStatusResponseAction.Status.ValueType  # 7
    """`UNAVAILABLE` (14) status code."""

    STATUS_FIELD_NUMBER: builtins.int
    status: global___GrpcStatusResponseAction.Status.ValueType
    """gRPC [status code](https://grpc.github.io/grpc/core/md_doc_statuscodes.html) to use in responses."""
    def __init__(
        self,
        *,
        status: global___GrpcStatusResponseAction.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___GrpcStatusResponseAction = GrpcStatusResponseAction

@typing.final
class HttpRouteAction(google.protobuf.message.Message):
    """An HTTP route action resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    HOST_REWRITE_FIELD_NUMBER: builtins.int
    AUTO_HOST_REWRITE_FIELD_NUMBER: builtins.int
    PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    UPGRADE_TYPES_FIELD_NUMBER: builtins.int
    RATE_LIMIT_FIELD_NUMBER: builtins.int
    REGEX_REWRITE_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """Backend group to forward requests to.

    Stream (TCP) backend groups are not supported.
    """
    host_rewrite: builtins.str
    """Host replacement."""
    auto_host_rewrite: builtins.bool
    """Automatically replaces the host with that of the target."""
    prefix_rewrite: builtins.str
    """Replacement for the path prefix matched by [StringMatch].

    For instance, if [StringMatch.prefix_match] value is `/foo` and `prefix_rewrite` value is `/bar`,
    a request with `/foobaz` path is forwarded with `/barbaz` path.
    For [StringMatch.exact_match], the whole path is replaced.

    If not specified, the path is not changed.

    Only one of regex_rewrite, or prefix_rewrite may be specified.
    """
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Overall timeout for an HTTP connection between a load balancer node an a backend from the backend group:
        the maximum time the connection is kept alive for, regardless of whether data is transferred over it.

        If a connection times out, the load balancer responds to the client with a `504 Gateway Timeout` status code.

        Default value: `60`.
        """

    @property
    def idle_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Idle timeout for an HTTP connection between a load balancer node an a backend from the backend group:
        the maximum time the connection is allowed to be idle, i.e. without any data transferred over it.

        Specifying meaningful values for both [timeout] and `idle_timeout` is useful for implementing
        server-push mechanisms such as long polling, server-sent events (`EventSource` interface) etc.

        If a connection times out, the load balancer responds to the client with a `504 Gateway Timeout` status code.

        If not specified, no idle timeout is used, and an alive connection may be idle for any duration (see [timeout]).
        """

    @property
    def upgrade_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Supported values for HTTP `Upgrade` header. E.g. `websocket`."""

    @property
    def rate_limit(self) -> yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit:
        """RateLimit is a rate limit configuration applied for route."""

    @property
    def regex_rewrite(self) -> global___RegexMatchAndSubstitute:
        """Replacement for portions of the path that match the pattern should be rewritten,
        even allowing the substitution of capture groups from the pattern into the new path as specified
        by the rewrite substitution string.

        Only one of regex_rewrite, or prefix_rewrite may be specified.

        Examples of using:
         - The path pattern ^/service/([^/]+)(/.*)$ paired with a substitution string of \\2/instance/\\1 would transform
           /service/foo/v1/api into /v1/api/instance/foo.
         - The pattern one paired with a substitution string of two would transform /xxx/one/yyy/one/zzz
           into /xxx/two/yyy/two/zzz.
         - The pattern ^(.*?)one(.*)$ paired with a substitution string of \\1two\\2 would replace only the first
           occurrence of one, transforming path /xxx/one/yyy/one/zzz into /xxx/two/yyy/one/zzz.
         - The pattern (?i)/xxx/ paired with a substitution string of /yyy/ would do a case-insensitive match and transform
           path /aaa/XxX/bbb to /aaa/yyy/bbb.
        """

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        idle_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        host_rewrite: builtins.str = ...,
        auto_host_rewrite: builtins.bool = ...,
        prefix_rewrite: builtins.str = ...,
        upgrade_types: collections.abc.Iterable[builtins.str] | None = ...,
        rate_limit: yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit | None = ...,
        regex_rewrite: global___RegexMatchAndSubstitute | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_host_rewrite", b"auto_host_rewrite", "host_rewrite", b"host_rewrite", "host_rewrite_specifier", b"host_rewrite_specifier", "idle_timeout", b"idle_timeout", "rate_limit", b"rate_limit", "regex_rewrite", b"regex_rewrite", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_host_rewrite", b"auto_host_rewrite", "backend_group_id", b"backend_group_id", "host_rewrite", b"host_rewrite", "host_rewrite_specifier", b"host_rewrite_specifier", "idle_timeout", b"idle_timeout", "prefix_rewrite", b"prefix_rewrite", "rate_limit", b"rate_limit", "regex_rewrite", b"regex_rewrite", "timeout", b"timeout", "upgrade_types", b"upgrade_types"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["host_rewrite_specifier", b"host_rewrite_specifier"]) -> typing.Literal["host_rewrite", "auto_host_rewrite"] | None: ...

global___HttpRouteAction = HttpRouteAction

@typing.final
class RegexMatchAndSubstitute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGEX_FIELD_NUMBER: builtins.int
    SUBSTITUTE_FIELD_NUMBER: builtins.int
    regex: builtins.str
    """The regular expression used to find portions of a string that should be replaced."""
    substitute: builtins.str
    """The string that should be substituted into matching portions of the subject string during a substitution operation
    to produce a new string.
    """
    def __init__(
        self,
        *,
        regex: builtins.str = ...,
        substitute: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["regex", b"regex", "substitute", b"substitute"]) -> None: ...

global___RegexMatchAndSubstitute = RegexMatchAndSubstitute

@typing.final
class GrpcRouteAction(google.protobuf.message.Message):
    """A gRPC route action resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_GROUP_ID_FIELD_NUMBER: builtins.int
    MAX_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    HOST_REWRITE_FIELD_NUMBER: builtins.int
    AUTO_HOST_REWRITE_FIELD_NUMBER: builtins.int
    RATE_LIMIT_FIELD_NUMBER: builtins.int
    backend_group_id: builtins.str
    """Backend group to forward requests to."""
    host_rewrite: builtins.str
    """Host replacement."""
    auto_host_rewrite: builtins.bool
    """Automatically replaces the host with that of the target."""
    @property
    def max_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Overall timeout for an underlying HTTP connection between a load balancer node an a backend from the backend group:
        the maximum time the connection is kept alive for, regardless of whether data is transferred over it.

        If a client specifies a lower timeout in HTTP `grpc-timeout` header, the `max_timeout` value is ignored.

        If a connection times out, the load balancer responds to the client with an `UNAVAILABLE` status code.

        Default value: `60`.
        """

    @property
    def idle_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Idle timeout for an underlying HTTP connection between a load balancer node an a backend from the backend group:
        the maximum time the connection is allowed to be idle, i.e. without any data transferred over it.

        Specifying meaningful values for both [max_timeout] and `idle_timeout` is useful for implementing
        server-push mechanisms such as long polling, server-sent events etc.

        If a connection times out, the load balancer responds to the client with an `UNAVAILABLE` status code.

        If not specified, no idle timeout is used, and an alive connection may be idle for any duration
        (see [max_timeout]).
        """

    @property
    def rate_limit(self) -> yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit:
        """RateLimit is a rate limit configuration applied for route."""

    def __init__(
        self,
        *,
        backend_group_id: builtins.str = ...,
        max_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        idle_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        host_rewrite: builtins.str = ...,
        auto_host_rewrite: builtins.bool = ...,
        rate_limit: yandex.cloud.apploadbalancer.v1.rate_limit_pb2.RateLimit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_host_rewrite", b"auto_host_rewrite", "host_rewrite", b"host_rewrite", "host_rewrite_specifier", b"host_rewrite_specifier", "idle_timeout", b"idle_timeout", "max_timeout", b"max_timeout", "rate_limit", b"rate_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_host_rewrite", b"auto_host_rewrite", "backend_group_id", b"backend_group_id", "host_rewrite", b"host_rewrite", "host_rewrite_specifier", b"host_rewrite_specifier", "idle_timeout", b"idle_timeout", "max_timeout", b"max_timeout", "rate_limit", b"rate_limit"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["host_rewrite_specifier", b"host_rewrite_specifier"]) -> typing.Literal["host_rewrite", "auto_host_rewrite"] | None: ...

global___GrpcRouteAction = GrpcRouteAction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOAuthClientRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the OAuthClient resource to return.
    To get the oauth client ID, use a [OAuthClientService.List] request.
    """
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id"]) -> None: ...

global___GetOAuthClientRequest = GetOAuthClientRequest

@typing.final
class ListOAuthClientsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListOAuthClientsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListOAuthClientsResponse.next_page_token] returned by a previous list request.
    """
    folder_id: builtins.str
    """ID of the folder to list oauth clients for
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOAuthClientsRequest = ListOAuthClientsRequest

@typing.final
class ListOAuthClientsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListOAuthClientsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListOAuthClientsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def oauth_clients(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OAuthClientListView]:
        """List of OAuthClient resource views"""

    def __init__(
        self,
        *,
        oauth_clients: collections.abc.Iterable[global___OAuthClientListView] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "oauth_clients", b"oauth_clients"]) -> None: ...

global___ListOAuthClientsResponse = ListOAuthClientsResponse

@typing.final
class OAuthClientListView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the OAuthClient resource."""
    name: builtins.str
    """Name of the OAuthClient resource."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___OAuthClientListView = OAuthClientListView

@typing.final
class UpdateOAuthClientMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the oauth client that is being updated"""
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id"]) -> None: ...

global___UpdateOAuthClientMetadata = UpdateOAuthClientMetadata

@typing.final
class DeleteOAuthClientMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the oauth client that is being deleted"""
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id"]) -> None: ...

global___DeleteOAuthClientMetadata = DeleteOAuthClientMetadata

@typing.final
class CreateOAuthClientRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REDIRECT_URIS_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the oauth client.
    The name must be unique within folder.
    """
    folder_id: builtins.str
    """ID of the folder to create an oauth client in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    @property
    def redirect_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of redirect uries allowed for the oauth client."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of oauth scopes requested by the oauth client."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        redirect_uris: collections.abc.Iterable[builtins.str] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "name", b"name", "redirect_uris", b"redirect_uris", "scopes", b"scopes"]) -> None: ...

global___CreateOAuthClientRequest = CreateOAuthClientRequest

@typing.final
class CreateOAuthClientMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the oauth client that is being created"""
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id"]) -> None: ...

global___CreateOAuthClientMetadata = CreateOAuthClientMetadata

@typing.final
class UpdateOAuthClientRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REDIRECT_URIS_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the OAuthClient resource to update.
    To get the oauth client ID, use a [OAuthClientService.List] request.
    """
    name: builtins.str
    """Name of the oauth client.
    The name must be unique within folder.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the OAuthClient resource are going to be updated."""

    @property
    def redirect_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of redirect uries allowed for the oauth client."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of oauth scopes requested by the oauth client."""

    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        redirect_uris: collections.abc.Iterable[builtins.str] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "oauth_client_id", b"oauth_client_id", "redirect_uris", b"redirect_uris", "scopes", b"scopes", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOAuthClientRequest = UpdateOAuthClientRequest

@typing.final
class DeleteOAuthClientRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the oauth client to delete.
    To get the oauth client ID, use [OAuthClientService.list] request.
    """
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id"]) -> None: ...

global___DeleteOAuthClientRequest = DeleteOAuthClientRequest



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import thumbnail_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2
from yandex.cloud.video.v1 import thumbnail_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/video/v1/thumbnail_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ThumbnailServiceStub(object):
    """Thumbnail management service.
    Provides methods for creating, retrieving, and managing thumbnail images
    that can be associated with various resources such as videos, streams, episodes, and channels.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/Get',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GetThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2.Thumbnail.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.BatchGenerateDownloadURLs = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
                _registered_method=True)
        self.GenerateUploadURL = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.video.v1.ThumbnailService/Delete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.DeleteThumbnailRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class ThumbnailServiceServicer(object):
    """Thumbnail management service.
    Provides methods for creating, retrieving, and managing thumbnail images
    that can be associated with various resources such as videos, streams, episodes, and channels.
    """

    def Get(self, request, context):
        """Retrieves detailed information about a specific thumbnail by its ID.
        Returns all thumbnail metadata and related information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all thumbnails associated with a specific resource (channel, stream, video, etc.)
        with pagination support.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new thumbnail record for a specific resource.
        This method only creates the metadata record; the actual image must be uploaded
        using the URL obtained from the GenerateUploadURL method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGenerateDownloadURLs(self, request, context):
        """Generates download URLs for multiple thumbnails in a single request.
        The response includes URLs for both original and scaled versions of each thumbnail.
        This is useful for efficiently retrieving multiple thumbnails at once.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateUploadURL(self, request, context):
        """Generates a URL for uploading an image to an existing thumbnail record.
        This URL can be used to upload the actual image file using an HTTP PUT request.
        The URL is pre-signed and has a limited validity period.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a specific thumbnail by its ID.
        This removes both the metadata record and the associated image file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ThumbnailServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GetThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2.Thumbnail.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchGenerateDownloadURLs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGenerateDownloadURLs,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.SerializeToString,
            ),
            'GenerateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateUploadURL,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.DeleteThumbnailRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.ThumbnailService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.video.v1.ThumbnailService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ThumbnailService(object):
    """Thumbnail management service.
    Provides methods for creating, retrieving, and managing thumbnail images
    that can be associated with various resources such as videos, streams, episodes, and channels.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/Get',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GetThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2.Thumbnail.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.ListThumbnailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.CreateThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGenerateDownloadURLs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/BatchGenerateDownloadURLs',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.BatchGenerateDownloadURLsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/GenerateUploadURL',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.GenerateThumbnailUploadURLResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.ThumbnailService/Delete',
            yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__service__pb2.DeleteThumbnailRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TextGenerationServiceStub:
    """Service for text generation."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Completion: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionResponse,
    ]
    """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode)."""

class TextGenerationServiceAsyncStub:
    """Service for text generation."""

    Completion: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionResponse,
    ]
    """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode)."""

class TextGenerationServiceServicer(metaclass=abc.ABCMeta):
    """Service for text generation."""

    @abc.abstractmethod
    def Completion(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionResponse], collections.abc.AsyncIterator[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionResponse]]:
        """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode)."""

def add_TextGenerationServiceServicer_to_server(servicer: TextGenerationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TextGenerationAsyncServiceStub:
    """Service for asynchronous text generation."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Completion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating text completions in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

class TextGenerationAsyncServiceAsyncStub:
    """Service for asynchronous text generation."""

    Completion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating text completions in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

class TextGenerationAsyncServiceServicer(metaclass=abc.ABCMeta):
    """Service for asynchronous text generation."""

    @abc.abstractmethod
    def Completion(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """A method for generating text completions in [asynchronous mode](/docs/foundation-models/concepts/#working-mode)."""

def add_TextGenerationAsyncServiceServicer_to_server(servicer: TextGenerationAsyncServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TextGenerationBatchServiceStub:
    """Service for text generation."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Completion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.BatchCompletionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode).
    Note: Not implemented yet
    """

class TextGenerationBatchServiceAsyncStub:
    """Service for text generation."""

    Completion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.BatchCompletionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode).
    Note: Not implemented yet
    """

class TextGenerationBatchServiceServicer(metaclass=abc.ABCMeta):
    """Service for text generation."""

    @abc.abstractmethod
    def Completion(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.BatchCompletionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode).
        Note: Not implemented yet
        """

def add_TextGenerationBatchServiceServicer_to_server(servicer: TextGenerationBatchServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TokenizerServiceStub:
    """Service for tokenizing input content."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Tokenize: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing text."""

    TokenizeCompletion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing content of CompletionRequest"""

class TokenizerServiceAsyncStub:
    """Service for tokenizing input content."""

    Tokenize: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing text."""

    TokenizeCompletion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing content of CompletionRequest"""

class TokenizerServiceServicer(metaclass=abc.ABCMeta):
    """Service for tokenizing input content."""

    @abc.abstractmethod
    def Tokenize(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse, collections.abc.Awaitable[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse]]:
        """RPC method for tokenizing text."""

    @abc.abstractmethod
    def TokenizeCompletion(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.CompletionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse, collections.abc.Awaitable[yandex.cloud.ai.foundation_models.v1.text_generation.text_generation_service_pb2.TokenizeResponse]]:
        """RPC method for tokenizing content of CompletionRequest"""

def add_TokenizerServiceServicer_to_server(servicer: TokenizerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/logging/v1/log_reading_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/logging/v1/log_reading_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/logging/v1/log_reading_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\"f\n\x0bReadRequest\x12\x14\n\npage_token\x18\x01 \x01(\tH\x00\x12\x35\n\x08\x63riteria\x18\x02 \x01(\x0b\x32!.yandex.cloud.logging.v1.CriteriaH\x00\x42\n\n\x08selector\"\x8e\x01\n\x0cReadResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\x32\n\x07\x65ntries\x18\x02 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\x12\x1b\n\x13previous_page_token\x18\x04 \x01(\t\"\xaa\x03\n\x08\x43riteria\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12)\n\x0eresource_types\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12\'\n\x0cresource_ids\x18\x03 \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12)\n\x05since\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06levels\x18\x06 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x0cstream_names\x18\n \x03(\tB\x11\x82\xc8\x31\x05<=100\x8a\xc8\x31\x04<=63\x12\x1d\n\tpage_size\x18\x08 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12)\n\x11max_response_size\x18\t \x01(\x03\x42\x0e\xfa\xc7\x31\n0-104857602h\n\x11LogReadingService\x12S\n\x04Read\x12$.yandex.cloud.logging.v1.ReadRequest\x1a%.yandex.cloud.logging.v1.ReadResponseBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_reading_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _globals['_CRITERIA'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_CRITERIA'].fields_by_name['resource_types']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['resource_types']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _globals['_CRITERIA'].fields_by_name['resource_ids']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['resource_ids']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _globals['_CRITERIA'].fields_by_name['levels']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['levels']._serialized_options = b'\202\3101\004<=10'
  _globals['_CRITERIA'].fields_by_name['filter']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CRITERIA'].fields_by_name['stream_names']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['stream_names']._serialized_options = b'\202\3101\005<=100\212\3101\004<=63'
  _globals['_CRITERIA'].fields_by_name['page_size']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_CRITERIA'].fields_by_name['max_response_size']._loaded_options = None
  _globals['_CRITERIA'].fields_by_name['max_response_size']._serialized_options = b'\372\3071\n0-10485760'
  _globals['_READREQUEST']._serialized_start=183
  _globals['_READREQUEST']._serialized_end=285
  _globals['_READRESPONSE']._serialized_start=288
  _globals['_READRESPONSE']._serialized_end=430
  _globals['_CRITERIA']._serialized_start=433
  _globals['_CRITERIA']._serialized_end=859
  _globals['_LOGREADINGSERVICE']._serialized_start=861
  _globals['_LOGREADINGSERVICE']._serialized_end=965
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Payload(google.protobuf.message.Message):
    """A payload."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Entry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        TEXT_VALUE_FIELD_NUMBER: builtins.int
        BINARY_VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Non-confidential key of the entry."""
        text_value: builtins.str
        """Text value."""
        binary_value: builtins.bytes
        """Binary value."""
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            text_value: builtins.str = ...,
            binary_value: builtins.bytes = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["binary_value", b"binary_value", "text_value", b"text_value", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["binary_value", b"binary_value", "key", b"key", "text_value", b"text_value", "value", b"value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["text_value", "binary_value"] | None: ...

    VERSION_ID_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    version_id: builtins.str
    """ID of the version that the payload belongs to."""
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Payload.Entry]:
        """Payload entries."""

    def __init__(
        self,
        *,
        version_id: builtins.str = ...,
        entries: collections.abc.Iterable[global___Payload.Entry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "version_id", b"version_id"]) -> None: ...

global___Payload = Payload



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Image(google.protobuf.message.Message):
    """An Image resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Image._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Image._Status.ValueType  # 0
        """Unspecified image status."""
        CREATING: Image._Status.ValueType  # 1
        """Image is being created."""
        READY: Image._Status.ValueType  # 2
        """Image is ready to use."""
        ERROR: Image._Status.ValueType  # 3
        """Image encountered an error."""
        DELETING: Image._Status.ValueType  # 4
        """Image is being deleted."""
        UPDATING: Image._Status.ValueType  # 5
        """Image is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Image status."""

    STATUS_UNSPECIFIED: Image.Status.ValueType  # 0
    """Unspecified image status."""
    CREATING: Image.Status.ValueType  # 1
    """Image is being created."""
    READY: Image.Status.ValueType  # 2
    """Image is ready to use."""
    ERROR: Image.Status.ValueType  # 3
    """Image encountered an error."""
    DELETING: Image.Status.ValueType  # 4
    """Image is being deleted."""
    UPDATING: Image.Status.ValueType  # 5
    """Image is being updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CHECKSUM_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the image."""
    folder_id: builtins.str
    """ID of the folder that the image belongs to."""
    name: builtins.str
    """Name of the image.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the image."""
    checksum: builtins.str
    """MD5 checksum of the image."""
    status: global___Image.Status.ValueType
    """Status of the image."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        checksum: builtins.str = ...,
        status: global___Image.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["checksum", b"checksum", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status"]) -> None: ...

global___Image = Image



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x1bgoogle/protobuf/empty.proto\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\".\n\x0f\x43lickhouseShard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\"\xd3\x01\n\x13OnPremiseClickhouse\x12\x46\n\x06shards\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.ClickhouseShard\x12\x11\n\thttp_port\x18\x03 \x01(\x03\x12\x13\n\x0bnative_port\x18\x04 \x01(\x03\x12@\n\x08tls_mode\x18\x08 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x08\"\xee\x02\n\x1b\x43lickhouseConnectionOptions\x12P\n\non_premise\x18\x02 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.OnPremiseClickhouseH\x00\x12k\n\x1d\x63onnection_manager_connection\x18\x03 \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.ConnectionManagerConnectionH\x00\x12\x18\n\x0emdb_cluster_id\x18\x05 \x01(\tH\x00\x12\x0c\n\x04user\x18\x06 \x01(\t\x12?\n\x08password\x18\x07 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08\x64\x61tabase\x18\x08 \x01(\tB\t\n\x07\x61\x64\x64ressJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\x86\x01\n\x14\x43lickhouseConnection\x12`\n\x12\x63onnection_options\x18\x01 \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnectionOptionsH\x00\x42\x0c\n\nconnection\"\xfc\x04\n\x12\x43lickhouseSharding\x12\x66\n\x11\x63olumn_value_hash\x18\x01 \x01(\x0b\x32I.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueHashH\x00\x12\x66\n\x0e\x63ustom_mapping\x18\x02 \x01(\x0b\x32L.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMappingH\x00\x12-\n\x0btransfer_id\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12-\n\x0bround_robin\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1a&\n\x0f\x43olumnValueHash\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x1a\x83\x02\n\x12\x43olumnValueMapping\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12j\n\x07mapping\x18\x02 \x03(\x0b\x32Y.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding.ColumnValueMapping.ValueToShard\x1al\n\x0cValueToShard\x12H\n\x0c\x63olumn_value\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.ColumnValue\x12\x12\n\nshard_name\x18\x02 \x01(\tB\n\n\x08sharding\"\xe6\x01\n\x10\x43lickhouseSource\x12O\n\nconnection\x18\x01 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x16\n\x0einclude_tables\x18\x07 \x03(\t\x12\x16\n\x0e\x65xclude_tables\x18\x08 \x03(\t\x12\x11\n\tsubnet_id\x18\t \x01(\t\x12\x17\n\x0fsecurity_groups\x18\n \x03(\t\x12\x1f\n\x17\x63lickhouse_cluster_name\x18\x0b \x01(\tJ\x04\x08\x02\x10\x07\"\xe2\x03\n\x10\x43lickhouseTarget\x12O\n\nconnection\x18\x02 \x01(\x0b\x32;.yandex.cloud.datatransfer.v1.endpoint.ClickhouseConnection\x12\x11\n\tsubnet_id\x18\x0c \x01(\t\x12\x41\n\talt_names\x18\x11 \x03(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.AltName\x12V\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32>.yandex.cloud.datatransfer.v1.endpoint.ClickhouseCleanupPolicy\x12K\n\x08sharding\x18\x16 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSharding\x12$\n\x1cis_schema_migration_disabled\x18# \x01(\x08\x12\x1f\n\x17\x63lickhouse_cluster_name\x18\x32 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x33 \x03(\tJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x0cJ\x04\x08\r\x10\x11J\x04\x08\x12\x10\x15J\x04\x08\x17\x10#J\x04\x08$\x10\x32*\xb8\x01\n\x17\x43lickhouseCleanupPolicy\x12)\n%CLICKHOUSE_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_DISABLED\x10\x01\x12\"\n\x1e\x43LICKHOUSE_CLEANUP_POLICY_DROP\x10\x02\x12&\n\"CLICKHOUSE_CLEANUP_POLICY_TRUNCATE\x10\x03\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_CLICKHOUSECLEANUPPOLICY']._serialized_start=2304
  _globals['_CLICKHOUSECLEANUPPOLICY']._serialized_end=2488
  _globals['_CLICKHOUSESHARD']._serialized_start=178
  _globals['_CLICKHOUSESHARD']._serialized_end=224
  _globals['_ONPREMISECLICKHOUSE']._serialized_start=227
  _globals['_ONPREMISECLICKHOUSE']._serialized_end=438
  _globals['_CLICKHOUSECONNECTIONOPTIONS']._serialized_start=441
  _globals['_CLICKHOUSECONNECTIONOPTIONS']._serialized_end=807
  _globals['_CLICKHOUSECONNECTION']._serialized_start=810
  _globals['_CLICKHOUSECONNECTION']._serialized_end=944
  _globals['_CLICKHOUSESHARDING']._serialized_start=947
  _globals['_CLICKHOUSESHARDING']._serialized_end=1583
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEHASH']._serialized_start=1271
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEHASH']._serialized_end=1309
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING']._serialized_start=1312
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING']._serialized_end=1571
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD']._serialized_start=1463
  _globals['_CLICKHOUSESHARDING_COLUMNVALUEMAPPING_VALUETOSHARD']._serialized_end=1571
  _globals['_CLICKHOUSESOURCE']._serialized_start=1586
  _globals['_CLICKHOUSESOURCE']._serialized_end=1816
  _globals['_CLICKHOUSETARGET']._serialized_start=1819
  _globals['_CLICKHOUSETARGET']._serialized_end=2301
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.stream_line_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line to retrieve."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___GetStreamLineRequest = GetStreamLineRequest

@typing.final
class ListStreamLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the stream lines to list."""
    page_size: builtins.int
    """The maximum number of stream lines to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListStreamLinesResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned stream lines.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'main' AND id='line-1'`

    Filterable fields: ["id", "title"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListStreamLinesRequest = ListStreamLinesRequest

@typing.final
class ListStreamLinesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def stream_lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_line_pb2.StreamLine]:
        """List of stream lines matching the request criteria.
        May be empty if no stream lines match the criteria or if the channel has no stream lines.
        """

    def __init__(
        self,
        *,
        stream_lines: collections.abc.Iterable[yandex.cloud.video.v1.stream_line_pb2.StreamLine] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "stream_lines", b"stream_lines"]) -> None: ...

global___ListStreamLinesResponse = ListStreamLinesResponse

@typing.final
class BatchGetStreamLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    STREAM_LINE_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the stream lines to retrieve."""
    @property
    def stream_line_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream line IDs to retrieve."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        stream_line_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "stream_line_ids", b"stream_line_ids"]) -> None: ...

global___BatchGetStreamLinesRequest = BatchGetStreamLinesRequest

@typing.final
class BatchGetStreamLinesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINES_FIELD_NUMBER: builtins.int
    @property
    def stream_lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_line_pb2.StreamLine]:
        """List of stream lines matching the requested IDs."""

    def __init__(
        self,
        *,
        stream_lines: collections.abc.Iterable[yandex.cloud.video.v1.stream_line_pb2.StreamLine] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_lines", b"stream_lines"]) -> None: ...

global___BatchGetStreamLinesResponse = BatchGetStreamLinesResponse

@typing.final
class CreateStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    RTMP_PUSH_FIELD_NUMBER: builtins.int
    RTMP_PULL_FIELD_NUMBER: builtins.int
    MANUAL_LINE_FIELD_NUMBER: builtins.int
    AUTO_LINE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Line title."""
    @property
    def rtmp_push(self) -> global___RTMPPushParams:
        """RTMP push input type."""

    @property
    def rtmp_pull(self) -> global___RTMPPullParams:
        """RTMP pull input type."""

    @property
    def manual_line(self) -> global___ManualLineParams:
        """Manual stream control."""

    @property
    def auto_line(self) -> global___AutoLineParams:
        """Automatic stream control."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as key:value pairs.
        Maximum 64 labels per stream line.
        Keys must be lowercase alphanumeric strings with optional hyphens/underscores.
        Values can contain alphanumeric characters and various symbols.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        rtmp_push: global___RTMPPushParams | None = ...,
        rtmp_pull: global___RTMPPullParams | None = ...,
        manual_line: global___ManualLineParams | None = ...,
        auto_line: global___AutoLineParams | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_line", b"auto_line", "input_params", b"input_params", "line_type_params", b"line_type_params", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_line", b"auto_line", "channel_id", b"channel_id", "input_params", b"input_params", "labels", b"labels", "line_type_params", b"line_type_params", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "title", b"title"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["input_params", b"input_params"]) -> typing.Literal["rtmp_push", "rtmp_pull"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["line_type_params", b"line_type_params"]) -> typing.Literal["manual_line", "auto_line"] | None: ...

global___CreateStreamLineRequest = CreateStreamLineRequest

@typing.final
class CreateStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___CreateStreamLineMetadata = CreateStreamLineMetadata

@typing.final
class UpdateStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    RTMP_PUSH_FIELD_NUMBER: builtins.int
    RTMP_PULL_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Line title."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the stream line should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def rtmp_push(self) -> global___RTMPPushParams:
        """RTMP push input type."""

    @property
    def rtmp_pull(self) -> global___RTMPPullParams:
        """RTMP pull input type."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New custom labels for the stream line as `key:value` pairs.
        Maximum 64 labels per stream line.
        If provided, replaces all existing labels.
        """

    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        rtmp_push: global___RTMPPushParams | None = ...,
        rtmp_pull: global___RTMPPullParams | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "input_params", b"input_params", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field_mask", b"field_mask", "input_params", b"input_params", "labels", b"labels", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "stream_line_id", b"stream_line_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["input_params", b"input_params"]) -> typing.Literal["rtmp_push", "rtmp_pull"] | None: ...

global___UpdateStreamLineRequest = UpdateStreamLineRequest

@typing.final
class UpdateStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamLineMetadata = UpdateStreamLineMetadata

@typing.final
class DeleteStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line to delete."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___DeleteStreamLineRequest = DeleteStreamLineRequest

@typing.final
class DeleteStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line.
    This identifier can be used to track the stream line deletion operation.
    """
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___DeleteStreamLineMetadata = DeleteStreamLineMetadata

@typing.final
class BatchDeleteStreamLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    STREAM_LINE_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the stream lines to delete."""
    @property
    def stream_line_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream line IDs to delete.
        All stream lines must exist in the specified channel.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        stream_line_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "stream_line_ids", b"stream_line_ids"]) -> None: ...

global___BatchDeleteStreamLinesRequest = BatchDeleteStreamLinesRequest

@typing.final
class BatchDeleteStreamLinesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_IDS_FIELD_NUMBER: builtins.int
    @property
    def stream_line_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of stream line IDs being deleted.
        This list can be used to track which stream lines are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        stream_line_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_ids", b"stream_line_ids"]) -> None: ...

global___BatchDeleteStreamLinesMetadata = BatchDeleteStreamLinesMetadata

@typing.final
class PerformLineActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    ACTIVATE_FIELD_NUMBER: builtins.int
    DEACTIVATE_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line on which to perform the action."""
    @property
    def activate(self) -> global___ActivateAction:
        """Activate the stream line, enabling it to receive and process video signals.
        This is typically used for automatic stream lines.
        """

    @property
    def deactivate(self) -> global___DeactivateAction:
        """Deactivate the stream line, disabling it from receiving and processing video signals.
        This is typically used for automatic stream lines.
        """

    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
        activate: global___ActivateAction | None = ...,
        deactivate: global___DeactivateAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "activate", b"activate", "deactivate", b"deactivate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "activate", b"activate", "deactivate", b"deactivate", "stream_line_id", b"stream_line_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["activate", "deactivate"] | None: ...

global___PerformLineActionRequest = PerformLineActionRequest

@typing.final
class PerformLineActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line on which the action is being performed.
    This identifier can be used to track the action operation
    and to verify that the action is being applied to the correct stream line.
    """
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___PerformLineActionMetadata = PerformLineActionMetadata

@typing.final
class RTMPPushParams(google.protobuf.message.Message):
    """Parameters for creating an RTMP push input type stream line."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RTMPPushParams = RTMPPushParams

@typing.final
class RTMPPullParams(google.protobuf.message.Message):
    """Parameters for creating an RTMP pull input type stream line."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """The RTMP URL from which to pull the video stream.
    Must be a valid RTMP URL starting with "rtmp://".
    """
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RTMPPullParams = RTMPPullParams

@typing.final
class ManualLineParams(google.protobuf.message.Message):
    """Parameters for manual stream line."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualLineParams = ManualLineParams

@typing.final
class AutoLineParams(google.protobuf.message.Message):
    """Parameters for auto stream line."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AutoLineParams = AutoLineParams

@typing.final
class ActivateAction(google.protobuf.message.Message):
    """Parameters for the activate action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ActivateAction = ActivateAction

@typing.final
class DeactivateAction(google.protobuf.message.Message):
    """Parameters for the deactivate action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeactivateAction = DeactivateAction

@typing.final
class GetStreamKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line for which to retrieve the stream key.
    The stream line must be a push-type input (RTMP push or SRT push).
    """
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___GetStreamKeyRequest = GetStreamKeyRequest

@typing.final
class UpdateStreamKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line for which to update the stream key.
    The stream line must be a push-type input (RTMP push or SRT push).
    """
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamKeyRequest = UpdateStreamKeyRequest

@typing.final
class UpdateStreamKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the stream line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamKeyMetadata = UpdateStreamKeyMetadata
